# oas-client

Generate typed python client from OpenAPI specification

## Installation

You can install the package via pip:

```
pip install oas-client
```

## Usage

```
oas-client <PATH>
```

## License

This project is licensed under the terms of the MIT license.
